from zope.interface import Interface


class IText(Interface):
    """
    text interface
    """


class IMeaning(Interface):
    """
    meaning interface
    """


class ITag(Interface):
    """
    tag interface
    """


class IWordform(Interface):
    """
    form interface
    """

class ISpeaker(Interface):
    """
    speaker interface
    """
